@@ -137,7 +137,10 @@ class HTTPClient(object):
         if 'data' in kwargs:
             curl.append('-d \'%s\'' % kwargs['data'])
 
-        curl.append('%s%s' % (self.endpoint, url))
+        if not parse.urlparse(url).netloc:
+            url = self.endpoint + url
+
+        curl.append(url)
         LOG.debug(' '.join(curl))
 
     @staticmethod
@@ -305,9 +308,6 @@ class SessionClient(adapter.LegacyJsonAdapter):
         redirect = kwargs.get('redirect')
         kwargs.setdefault('user_agent', USER_AGENT)
 
-        headers = kwargs.setdefault('headers', {})
-        headers.setdefault('Content-Type', 'application/json')
-
         if 'data' in kwargs:
             kwargs['data'] = jsonutils.dumps(kwargs['data'])
 
@@ -358,6 +358,10 @@ def _construct_http_client(endpoint=None, username=None, password=None,
         if 'interface' not in kwargs and endpoint_type:
             kwargs['interface'] = endpoint_type
 
+        if 'region_name' in kwargs:
+            kwargs['additional_headers'] = {
+                'X-Region-Name': kwargs['region_name']}
+
         return SessionClient(session, auth=auth, **kwargs)
     else:
         return HTTPClient(endpoint=endpoint, username=username,
